# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/exchange.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/exchange/v1beta1/exchange.proto',
  package='injective.exchange.v1beta1',
  syntax='proto3',
  serialized_options=b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)injective/exchange/v1beta1/exchange.proto\x12\x1ainjective.exchange.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\xa7\t\n\x06Params\x12H\n\x1fspot_market_instant_listing_fee\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12N\n%derivative_market_instant_listing_fee\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12S\n\x1b\x64\x65\x66\x61ult_spot_maker_fee_rate\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12S\n\x1b\x64\x65\x66\x61ult_spot_taker_fee_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Y\n!default_derivative_maker_fee_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Y\n!default_derivative_taker_fee_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12T\n\x1c\x64\x65\x66\x61ult_initial_margin_ratio\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12X\n default_maintenance_margin_ratio\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12 \n\x18\x64\x65\x66\x61ult_funding_interval\x18\t \x01(\x03\x12\x18\n\x10\x66unding_multiple\x18\n \x01(\x03\x12N\n\x16relayer_fee_share_rate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12W\n\x1f\x64\x65\x66\x61ult_hourly_funding_rate_cap\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12T\n\x1c\x64\x65\x66\x61ult_hourly_interest_rate\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\'\n\x1fmax_derivative_order_side_count\x18\x0e \x01(\r\x12_\n\'inj_reward_staked_requirement_threshold\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12(\n trading_rewards_vesting_duration\x18\x10 \x01(\x03:\x04\xe8\xa0\x1f\x01\"\xb9\x06\n\x10\x44\x65rivativeMarket\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12\x13\n\x0boracle_base\x18\x02 \x01(\t\x12\x14\n\x0coracle_quote\x18\x03 \x01(\t\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x05 \x01(\r\x12\x13\n\x0bquote_denom\x18\x06 \x01(\t\x12\x11\n\tmarket_id\x18\x07 \x01(\t\x12L\n\x14initial_margin_ratio\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0emaker_fee_rate\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16relayer_fee_share_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x13\n\x0bisPerpetual\x18\r \x01(\x08\x12\x38\n\x06status\x18\x0e \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12K\n\x13min_price_tick_size\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x10 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x92\x02\n\x17\x45xpiryFuturesMarketInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpiration_timestamp\x18\x02 \x01(\x03\x12\x1c\n\x14twap_start_timestamp\x18\x03 \x01(\x03\x12^\n&expiration_twap_start_price_cumulative\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10settlement_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x81\x02\n\x13PerpetualMarketInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12O\n\x17hourly_funding_rate_cap\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14hourly_interest_rate\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x1e\n\x16next_funding_timestamp\x18\x04 \x01(\x03\x12\x18\n\x10\x66unding_interval\x18\x05 \x01(\x03\"\xc6\x01\n\x16PerpetualMarketFunding\x12J\n\x12\x63umulative_funding\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x63umulative_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x16\n\x0elast_timestamp\x18\x03 \x01(\x03\"\xc7\x01\n\x1e\x44\x65rivativeMarketSettlementInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12H\n\x10settlement_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10starting_deficit\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\".\n\x14NextFundingTimestamp\x12\x16\n\x0enext_timestamp\x18\x01 \x01(\x03\"\x8f\x04\n\nSpotMarket\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12\x12\n\nbase_denom\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\tmarket_id\x18\x07 \x01(\t\x12\x38\n\x06status\x18\x08 \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12K\n\x13min_price_tick_size\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x9b\x01\n\x07\x44\x65posit\x12I\n\x11\x61vailable_balance\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtotal_balance\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"%\n\x14SubaccountTradeNonce\x12\r\n\x05nonce\x18\x01 \x01(\r\"\xba\x01\n\tOrderInfo\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x15\n\rfee_recipient\x18\x02 \x01(\t\x12=\n\x05price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xe1\x01\n\tSpotOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12?\n\norder_info\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x03 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12\x45\n\rtrigger_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"\xa9\x02\n\x0eSpotLimitOrder\x12?\n\norder_info\x18\x01 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x02 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12@\n\x08\x66illable\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtrigger_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x12\n\norder_hash\x18\x05 \x01(\x0c\"\xac\x01\n\x0fSpotMarketOrder\x12?\n\norder_info\x18\x01 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x44\n\x0c\x62\x61lance_hold\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x12\n\norder_hash\x18\x03 \x01(\x0c\"\xa7\x02\n\x0f\x44\x65rivativeOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12?\n\norder_info\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x03 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12>\n\x06margin\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtrigger_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"\x93\x02\n\x1bSubaccountOrderbookMetadata\x12!\n\x19vanilla_limit_order_count\x18\x01 \x01(\r\x12%\n\x1dreduce_only_limit_order_count\x18\x02 \x01(\r\x12V\n\x1e\x61ggregate_reduce_only_quantity\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12R\n\x1a\x61ggregate_vanilla_quantity\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xa8\x01\n\x0fSubaccountOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0cisReduceOnly\x18\x03 \x01(\x08\"\xef\x02\n\x14\x44\x65rivativeLimitOrder\x12?\n\norder_info\x18\x01 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x02 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12>\n\x06margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08\x66illable\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtrigger_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x12\n\norder_hash\x18\x06 \x01(\x0c\"\xf3\x02\n\x15\x44\x65rivativeMarketOrder\x12?\n\norder_info\x18\x01 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x02 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12>\n\x06margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0bmargin_hold\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtrigger_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x12\n\norder_hash\x18\x06 \x01(\x0c\"\xb3\x02\n\x08Position\x12\x0e\n\x06isLong\x18\x01 \x01(\x08\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x65ntry_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x06margin\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18\x63umulative_funding_entry\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"8\n\x14MarketOrderIndicator\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\r\n\x05isBuy\x18\x02 \x01(\x08\"\x98\x02\n\x08TradeLog\x12@\n\x08quantity\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x15\n\rsubaccount_id\x18\x03 \x01(\x0c\x12;\n\x03\x66\x65\x65\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x12\n\norder_hash\x18\x05 \x01(\x0c\x12#\n\x15\x66\x65\x65_recipient_address\x18\x06 \x01(\x0c\x42\x04\xc8\xde\x1f\x01\"\xff\x01\n\rPositionDelta\x12\x0f\n\x07is_long\x18\x01 \x01(\x08\x12J\n\x12\x65xecution_quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x65xecution_margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0f\x65xecution_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xa4\x02\n\x12\x44\x65rivativeTradeLog\x12\x15\n\rsubaccount_id\x18\x01 \x01(\x0c\x12\x41\n\x0eposition_delta\x18\x02 \x01(\x0b\x32).injective.exchange.v1beta1.PositionDelta\x12>\n\x06payout\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12;\n\x03\x66\x65\x65\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x12\n\norder_hash\x18\x05 \x01(\x0c\x12#\n\x15\x66\x65\x65_recipient_address\x18\x06 \x01(\x0c\x42\x04\xc8\xde\x1f\x01\"\xb4\x01\n\x17\x45ventBatchSpotExecution\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0e\n\x06is_buy\x18\x02 \x01(\x08\x12@\n\rexecutionType\x18\x03 \x01(\x0e\x32).injective.exchange.v1beta1.ExecutionType\x12\x34\n\x06trades\x18\x04 \x03(\x0b\x32$.injective.exchange.v1beta1.TradeLog\"\xa8\x02\n\x1d\x45ventBatchDerivativeExecution\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x0e\n\x06is_buy\x18\x02 \x01(\x08\x12\x16\n\x0eis_liquidation\x18\x03 \x01(\x08\x12J\n\x12\x63umulative_funding\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12@\n\rexecutionType\x18\x05 \x01(\x0e\x32).injective.exchange.v1beta1.ExecutionType\x12>\n\x06trades\x18\x06 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativeTradeLog\"\x81\x02\n\x1d\x45ventLostFundsFromLiquidation\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\x0c\x12_\n\'lost_funds_from_available_during_payout\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12U\n\x1dlost_funds_from_order_cancels\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"c\n\x12SubaccountPosition\x12\x36\n\x08position\x18\x01 \x01(\x0b\x32$.injective.exchange.v1beta1.Position\x12\x15\n\rsubaccount_id\x18\x02 \x01(\x0c\"t\n\x1c\x45ventBatchDerivativePosition\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x41\n\tpositions\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.SubaccountPosition\"\x7f\n\x1b\x45ventDerivativeMarketPaused\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x14\n\x0csettle_price\x18\x02 \x01(\t\x12\x1b\n\x13total_missing_funds\x18\x03 \x01(\t\x12\x1a\n\x12missing_funds_rate\x18\x04 \x01(\t\"\xa8\x01\n\x12\x45ventNewSpotOrders\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12>\n\nbuy_orders\x18\x02 \x03(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrder\x12?\n\x0bsell_orders\x18\x03 \x03(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrder\"\xba\x01\n\x18\x45ventNewDerivativeOrders\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x44\n\nbuy_orders\x18\x02 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder\x12\x45\n\x0bsell_orders\x18\x03 \x03(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrder\"j\n\x14\x45ventCancelSpotOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12?\n\x05order\x18\x02 \x01(\x0b\x32*.injective.exchange.v1beta1.SpotLimitOrderB\x04\xc8\xde\x1f\x00\"U\n\x15\x45ventSpotMarketUpdate\x12<\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarketB\x04\xc8\xde\x1f\x00\"\x81\x02\n\x1a\x45ventPerpetualMarketUpdate\x12\x42\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarketB\x04\xc8\xde\x1f\x00\x12T\n\x15perpetual_market_info\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x01\x12I\n\x07\x66unding\x18\x03 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x01\"\xc3\x01\n\x1e\x45ventExpiryFuturesMarketUpdate\x12\x42\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarketB\x04\xc8\xde\x1f\x00\x12]\n\x1a\x65xpiry_futures_market_info\x18\x03 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x01\"\xa6\x02\n!EventPerpetualMarketFundingUpdate\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12I\n\x07\x66unding\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00\x12\x19\n\x11is_hourly_funding\x18\x03 \x01(\x08\x12\x44\n\x0c\x66unding_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x42\n\nmark_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"u\n\x16\x45ventSubaccountDeposit\x12\x13\n\x0bsrc_address\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\x0c\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"v\n\x17\x45ventSubaccountWithdraw\x12\x15\n\rsubaccount_id\x18\x01 \x01(\x0c\x12\x13\n\x0b\x64st_address\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x87\x01\n\x1e\x45ventSubaccountBalanceTransfer\x12\x19\n\x11src_subaccount_id\x18\x01 \x01(\t\x12\x19\n\x11\x64st_subaccount_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"`\n\x11SubaccountDeposit\x12\x15\n\rsubaccount_id\x18\x01 \x01(\x0c\x12\x34\n\x07\x64\x65posit\x18\x02 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit\"_\n\rDepositUpdate\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12?\n\x08\x64\x65posits\x18\x02 \x03(\x0b\x32-.injective.exchange.v1beta1.SubaccountDeposit\"]\n\x17\x45ventBatchDepositUpdate\x12\x42\n\x0f\x64\x65posit_updates\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.DepositUpdate\"\xb5\x01\n\x1b\x44\x65rivativeMarketOrderCancel\x12M\n\x0cmarket_order\x18\x01 \x01(\x0b\x32\x31.injective.exchange.v1beta1.DerivativeMarketOrderB\x04\xc8\xde\x1f\x01\x12G\n\x0f\x63\x61ncel_quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xef\x01\n\x1a\x45ventCancelDerivativeOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\risLimitCancel\x18\x02 \x01(\x08\x12K\n\x0blimit_order\x18\x03 \x01(\x0b\x32\x30.injective.exchange.v1beta1.DerivativeLimitOrderB\x04\xc8\xde\x1f\x01\x12Z\n\x13market_order_cancel\x18\x04 \x01(\x0b\x32\x37.injective.exchange.v1beta1.DerivativeMarketOrderCancelB\x04\xc8\xde\x1f\x01\"\xb4\x01\n\x10PointsMultiplier\x12O\n\x17maker_points_multiplier\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17taker_points_multiplier\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x98\x02\n\x1eTradingRewardCampaignBoostInfo\x12\x1f\n\x17\x62oosted_spot_market_ids\x18\x01 \x03(\t\x12S\n\x17spot_market_multipliers\x18\x02 \x03(\x0b\x32,.injective.exchange.v1beta1.PointsMultiplierB\x04\xc8\xde\x1f\x00\x12%\n\x1d\x62oosted_derivative_market_ids\x18\x03 \x03(\t\x12Y\n\x1d\x64\x65rivative_market_multipliers\x18\x04 \x03(\x0b\x32,.injective.exchange.v1beta1.PointsMultiplierB\x04\xc8\xde\x1f\x00\"\x98\x01\n\x12\x43\x61mpaignRewardPool\x12\x17\n\x0fstart_timestamp\x18\x01 \x01(\x03\x12i\n\x14max_campaign_rewards\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\xd4\x01\n\x19TradingRewardCampaignInfo\x12!\n\x19\x63\x61mpaign_duration_seconds\x18\x01 \x01(\x03\x12\x14\n\x0cquote_denoms\x18\x02 \x03(\t\x12]\n\x19trading_reward_boost_info\x18\x03 \x01(\x0b\x32:.injective.exchange.v1beta1.TradingRewardCampaignBoostInfo\x12\x1f\n\x17\x64isqualified_market_ids\x18\x04 \x03(\t\"\xbf\x02\n\x13\x46\x65\x65\x44iscountTierInfo\x12K\n\x13maker_discount_rate\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13taker_discount_rate\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rstaked_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12G\n\x0f\x66\x65\x65_paid_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xc0\x01\n\x13\x46\x65\x65\x44iscountSchedule\x12\x14\n\x0c\x62ucket_count\x18\x01 \x01(\x04\x12\x17\n\x0f\x62ucket_duration\x18\x02 \x01(\x03\x12\x14\n\x0cquote_denoms\x18\x03 \x03(\t\x12\x43\n\ntier_infos\x18\x04 \x03(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountTierInfo\x12\x1f\n\x17\x64isqualified_market_ids\x18\x05 \x03(\t\"9\n\x12\x46\x65\x65\x44iscountTierTTL\x12\x0c\n\x04tier\x18\x01 \x01(\x04\x12\x15\n\rttl_timestamp\x18\x02 \x01(\x03\"]\n\x18\x45ventFeeDiscountSchedule\x12\x41\n\x08schedule\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule\"\xbf\x01\n EventTradingRewardCampaignUpdate\x12L\n\rcampaign_info\x18\x01 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12M\n\x15\x63\x61mpaign_reward_pools\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\"\x7f\n\x0e\x41\x63\x63ountRewards\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\\\n\x07rewards\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"e\n\x1e\x45ventTradingRewardDistribution\x12\x43\n\x0f\x61\x63\x63ount_rewards\x18\x01 \x03(\x0b\x32*.injective.exchange.v1beta1.AccountRewards*c\n\x0cMarketStatus\x12\x0f\n\x0bUnspecified\x10\x00\x12\n\n\x06\x41\x63tive\x10\x01\x12\n\n\x06Paused\x10\x02\x12\r\n\tSuspended\x10\x03\x12\x0e\n\nDemolished\x10\x04\x12\x0b\n\x07\x45xpired\x10\x05*\xf9\x01\n\tOrderType\x12 \n\x0bUNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12\x10\n\x03\x42UY\x10\x01\x1a\x07\x8a\x9d \x03\x42UY\x12\x12\n\x04SELL\x10\x02\x1a\x08\x8a\x9d \x04SELL\x12\x1a\n\x08STOP_BUY\x10\x03\x1a\x0c\x8a\x9d \x08STOP_BUY\x12\x1c\n\tSTOP_SELL\x10\x04\x1a\r\x8a\x9d \tSTOP_SELL\x12\x1a\n\x08TAKE_BUY\x10\x05\x1a\x0c\x8a\x9d \x08TAKE_BUY\x12\x1c\n\tTAKE_SELL\x10\x06\x1a\r\x8a\x9d \tTAKE_SELL\x12\x16\n\x06\x42UY_PO\x10\x07\x1a\n\x8a\x9d \x06\x42UY_PO\x12\x18\n\x07SELL_PO\x10\x08\x1a\x0b\x8a\x9d \x07SELL_PO*\xaf\x01\n\rExecutionType\x12\x1c\n\x18UnspecifiedExecutionType\x10\x00\x12\n\n\x06Market\x10\x01\x12\r\n\tLimitFill\x10\x02\x12\x1a\n\x16LimitMatchRestingOrder\x10\x03\x12\x16\n\x12LimitMatchNewOrder\x10\x04\x12\x15\n\x11MarketLiquidation\x10\x05\x12\x1a\n\x16\x45xpiryMarketSettlement\x10\x06\x42PZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,])

_MARKETSTATUS = _descriptor.EnumDescriptor(
  name='MarketStatus',
  full_name='injective.exchange.v1beta1.MarketStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Unspecified', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Active', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Paused', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Suspended', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Demolished', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Expired', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12916,
  serialized_end=13015,
)
_sym_db.RegisterEnumDescriptor(_MARKETSTATUS)

MarketStatus = enum_type_wrapper.EnumTypeWrapper(_MARKETSTATUS)
_ORDERTYPE = _descriptor.EnumDescriptor(
  name='OrderType',
  full_name='injective.exchange.v1beta1.OrderType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=b'\212\235 \013UNSPECIFIED',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUY', index=1, number=1,
      serialized_options=b'\212\235 \003BUY',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SELL', index=2, number=2,
      serialized_options=b'\212\235 \004SELL',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_BUY', index=3, number=3,
      serialized_options=b'\212\235 \010STOP_BUY',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_SELL', index=4, number=4,
      serialized_options=b'\212\235 \tSTOP_SELL',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TAKE_BUY', index=5, number=5,
      serialized_options=b'\212\235 \010TAKE_BUY',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TAKE_SELL', index=6, number=6,
      serialized_options=b'\212\235 \tTAKE_SELL',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUY_PO', index=7, number=7,
      serialized_options=b'\212\235 \006BUY_PO',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SELL_PO', index=8, number=8,
      serialized_options=b'\212\235 \007SELL_PO',
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13018,
  serialized_end=13267,
)
_sym_db.RegisterEnumDescriptor(_ORDERTYPE)

OrderType = enum_type_wrapper.EnumTypeWrapper(_ORDERTYPE)
_EXECUTIONTYPE = _descriptor.EnumDescriptor(
  name='ExecutionType',
  full_name='injective.exchange.v1beta1.ExecutionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnspecifiedExecutionType', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Market', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LimitFill', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LimitMatchRestingOrder', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LimitMatchNewOrder', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MarketLiquidation', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ExpiryMarketSettlement', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=13270,
  serialized_end=13445,
)
_sym_db.RegisterEnumDescriptor(_EXECUTIONTYPE)

ExecutionType = enum_type_wrapper.EnumTypeWrapper(_EXECUTIONTYPE)
Unspecified = 0
Active = 1
Paused = 2
Suspended = 3
Demolished = 4
Expired = 5
UNSPECIFIED = 0
BUY = 1
SELL = 2
STOP_BUY = 3
STOP_SELL = 4
TAKE_BUY = 5
TAKE_SELL = 6
BUY_PO = 7
SELL_PO = 8
UnspecifiedExecutionType = 0
Market = 1
LimitFill = 2
LimitMatchRestingOrder = 3
LimitMatchNewOrder = 4
MarketLiquidation = 5
ExpiryMarketSettlement = 6



_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.exchange.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spot_market_instant_listing_fee', full_name='injective.exchange.v1beta1.Params.spot_market_instant_listing_fee', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_market_instant_listing_fee', full_name='injective.exchange.v1beta1.Params.derivative_market_instant_listing_fee', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_spot_maker_fee_rate', full_name='injective.exchange.v1beta1.Params.default_spot_maker_fee_rate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_spot_taker_fee_rate', full_name='injective.exchange.v1beta1.Params.default_spot_taker_fee_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_derivative_maker_fee_rate', full_name='injective.exchange.v1beta1.Params.default_derivative_maker_fee_rate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_derivative_taker_fee_rate', full_name='injective.exchange.v1beta1.Params.default_derivative_taker_fee_rate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_initial_margin_ratio', full_name='injective.exchange.v1beta1.Params.default_initial_margin_ratio', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_maintenance_margin_ratio', full_name='injective.exchange.v1beta1.Params.default_maintenance_margin_ratio', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_funding_interval', full_name='injective.exchange.v1beta1.Params.default_funding_interval', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding_multiple', full_name='injective.exchange.v1beta1.Params.funding_multiple', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayer_fee_share_rate', full_name='injective.exchange.v1beta1.Params.relayer_fee_share_rate', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_hourly_funding_rate_cap', full_name='injective.exchange.v1beta1.Params.default_hourly_funding_rate_cap', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_hourly_interest_rate', full_name='injective.exchange.v1beta1.Params.default_hourly_interest_rate', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_derivative_order_side_count', full_name='injective.exchange.v1beta1.Params.max_derivative_order_side_count', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inj_reward_staked_requirement_threshold', full_name='injective.exchange.v1beta1.Params.inj_reward_staked_requirement_threshold', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_rewards_vesting_duration', full_name='injective.exchange.v1beta1.Params.trading_rewards_vesting_duration', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=1358,
)


_DERIVATIVEMARKET = _descriptor.Descriptor(
  name='DerivativeMarket',
  full_name='injective.exchange.v1beta1.DerivativeMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.DerivativeMarket.ticker', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.exchange.v1beta1.DerivativeMarket.oracle_base', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.exchange.v1beta1.DerivativeMarket.oracle_quote', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.exchange.v1beta1.DerivativeMarket.oracle_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_scale_factor', full_name='injective.exchange.v1beta1.DerivativeMarket.oracle_scale_factor', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.DerivativeMarket.quote_denom', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.DerivativeMarket.market_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_margin_ratio', full_name='injective.exchange.v1beta1.DerivativeMarket.initial_margin_ratio', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maintenance_margin_ratio', full_name='injective.exchange.v1beta1.DerivativeMarket.maintenance_margin_ratio', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.DerivativeMarket.maker_fee_rate', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.DerivativeMarket.taker_fee_rate', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayer_fee_share_rate', full_name='injective.exchange.v1beta1.DerivativeMarket.relayer_fee_share_rate', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isPerpetual', full_name='injective.exchange.v1beta1.DerivativeMarket.isPerpetual', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.DerivativeMarket.status', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.DerivativeMarket.min_price_tick_size', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.DerivativeMarket.min_quantity_tick_size', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=2186,
)


_EXPIRYFUTURESMARKETINFO = _descriptor.Descriptor(
  name='ExpiryFuturesMarketInfo',
  full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfo.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_timestamp', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfo.expiration_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='twap_start_timestamp', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfo.twap_start_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_twap_start_price_cumulative', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfo.expiration_twap_start_price_cumulative', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='injective.exchange.v1beta1.ExpiryFuturesMarketInfo.settlement_price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2189,
  serialized_end=2463,
)


_PERPETUALMARKETINFO = _descriptor.Descriptor(
  name='PerpetualMarketInfo',
  full_name='injective.exchange.v1beta1.PerpetualMarketInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.PerpetualMarketInfo.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hourly_funding_rate_cap', full_name='injective.exchange.v1beta1.PerpetualMarketInfo.hourly_funding_rate_cap', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hourly_interest_rate', full_name='injective.exchange.v1beta1.PerpetualMarketInfo.hourly_interest_rate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_funding_timestamp', full_name='injective.exchange.v1beta1.PerpetualMarketInfo.next_funding_timestamp', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding_interval', full_name='injective.exchange.v1beta1.PerpetualMarketInfo.funding_interval', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2466,
  serialized_end=2723,
)


_PERPETUALMARKETFUNDING = _descriptor.Descriptor(
  name='PerpetualMarketFunding',
  full_name='injective.exchange.v1beta1.PerpetualMarketFunding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cumulative_funding', full_name='injective.exchange.v1beta1.PerpetualMarketFunding.cumulative_funding', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_price', full_name='injective.exchange.v1beta1.PerpetualMarketFunding.cumulative_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_timestamp', full_name='injective.exchange.v1beta1.PerpetualMarketFunding.last_timestamp', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2726,
  serialized_end=2924,
)


_DERIVATIVEMARKETSETTLEMENTINFO = _descriptor.Descriptor(
  name='DerivativeMarketSettlementInfo',
  full_name='injective.exchange.v1beta1.DerivativeMarketSettlementInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.DerivativeMarketSettlementInfo.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settlement_price', full_name='injective.exchange.v1beta1.DerivativeMarketSettlementInfo.settlement_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='starting_deficit', full_name='injective.exchange.v1beta1.DerivativeMarketSettlementInfo.starting_deficit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2927,
  serialized_end=3126,
)


_NEXTFUNDINGTIMESTAMP = _descriptor.Descriptor(
  name='NextFundingTimestamp',
  full_name='injective.exchange.v1beta1.NextFundingTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_timestamp', full_name='injective.exchange.v1beta1.NextFundingTimestamp.next_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3128,
  serialized_end=3174,
)


_SPOTMARKET = _descriptor.Descriptor(
  name='SpotMarket',
  full_name='injective.exchange.v1beta1.SpotMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.exchange.v1beta1.SpotMarket.ticker', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_denom', full_name='injective.exchange.v1beta1.SpotMarket.base_denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.exchange.v1beta1.SpotMarket.quote_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maker_fee_rate', full_name='injective.exchange.v1beta1.SpotMarket.maker_fee_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_fee_rate', full_name='injective.exchange.v1beta1.SpotMarket.taker_fee_rate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayer_fee_share_rate', full_name='injective.exchange.v1beta1.SpotMarket.relayer_fee_share_rate', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.SpotMarket.market_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.SpotMarket.status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price_tick_size', full_name='injective.exchange.v1beta1.SpotMarket.min_price_tick_size', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_quantity_tick_size', full_name='injective.exchange.v1beta1.SpotMarket.min_quantity_tick_size', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3177,
  serialized_end=3704,
)


_DEPOSIT = _descriptor.Descriptor(
  name='Deposit',
  full_name='injective.exchange.v1beta1.Deposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='available_balance', full_name='injective.exchange.v1beta1.Deposit.available_balance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_balance', full_name='injective.exchange.v1beta1.Deposit.total_balance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3707,
  serialized_end=3862,
)


_SUBACCOUNTTRADENONCE = _descriptor.Descriptor(
  name='SubaccountTradeNonce',
  full_name='injective.exchange.v1beta1.SubaccountTradeNonce',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.exchange.v1beta1.SubaccountTradeNonce.nonce', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3864,
  serialized_end=3901,
)


_ORDERINFO = _descriptor.Descriptor(
  name='OrderInfo',
  full_name='injective.exchange.v1beta1.OrderInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.OrderInfo.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_recipient', full_name='injective.exchange.v1beta1.OrderInfo.fee_recipient', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.exchange.v1beta1.OrderInfo.price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.OrderInfo.quantity', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3904,
  serialized_end=4090,
)


_SPOTORDER = _descriptor.Descriptor(
  name='SpotOrder',
  full_name='injective.exchange.v1beta1.SpotOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.SpotOrder.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_info', full_name='injective.exchange.v1beta1.SpotOrder.order_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective.exchange.v1beta1.SpotOrder.order_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective.exchange.v1beta1.SpotOrder.trigger_price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4093,
  serialized_end=4318,
)


_SPOTLIMITORDER = _descriptor.Descriptor(
  name='SpotLimitOrder',
  full_name='injective.exchange.v1beta1.SpotLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_info', full_name='injective.exchange.v1beta1.SpotLimitOrder.order_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective.exchange.v1beta1.SpotLimitOrder.order_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fillable', full_name='injective.exchange.v1beta1.SpotLimitOrder.fillable', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective.exchange.v1beta1.SpotLimitOrder.trigger_price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.SpotLimitOrder.order_hash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4321,
  serialized_end=4618,
)


_SPOTMARKETORDER = _descriptor.Descriptor(
  name='SpotMarketOrder',
  full_name='injective.exchange.v1beta1.SpotMarketOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_info', full_name='injective.exchange.v1beta1.SpotMarketOrder.order_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance_hold', full_name='injective.exchange.v1beta1.SpotMarketOrder.balance_hold', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.SpotMarketOrder.order_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4621,
  serialized_end=4793,
)


_DERIVATIVEORDER = _descriptor.Descriptor(
  name='DerivativeOrder',
  full_name='injective.exchange.v1beta1.DerivativeOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.DerivativeOrder.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_info', full_name='injective.exchange.v1beta1.DerivativeOrder.order_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective.exchange.v1beta1.DerivativeOrder.order_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective.exchange.v1beta1.DerivativeOrder.margin', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective.exchange.v1beta1.DerivativeOrder.trigger_price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4796,
  serialized_end=5091,
)


_SUBACCOUNTORDERBOOKMETADATA = _descriptor.Descriptor(
  name='SubaccountOrderbookMetadata',
  full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vanilla_limit_order_count', full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadata.vanilla_limit_order_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reduce_only_limit_order_count', full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadata.reduce_only_limit_order_count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregate_reduce_only_quantity', full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadata.aggregate_reduce_only_quantity', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregate_vanilla_quantity', full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadata.aggregate_vanilla_quantity', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5094,
  serialized_end=5369,
)


_SUBACCOUNTORDER = _descriptor.Descriptor(
  name='SubaccountOrder',
  full_name='injective.exchange.v1beta1.SubaccountOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.exchange.v1beta1.SubaccountOrder.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.SubaccountOrder.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isReduceOnly', full_name='injective.exchange.v1beta1.SubaccountOrder.isReduceOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5372,
  serialized_end=5540,
)


_DERIVATIVELIMITORDER = _descriptor.Descriptor(
  name='DerivativeLimitOrder',
  full_name='injective.exchange.v1beta1.DerivativeLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_info', full_name='injective.exchange.v1beta1.DerivativeLimitOrder.order_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective.exchange.v1beta1.DerivativeLimitOrder.order_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective.exchange.v1beta1.DerivativeLimitOrder.margin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fillable', full_name='injective.exchange.v1beta1.DerivativeLimitOrder.fillable', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective.exchange.v1beta1.DerivativeLimitOrder.trigger_price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.DerivativeLimitOrder.order_hash', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5543,
  serialized_end=5910,
)


_DERIVATIVEMARKETORDER = _descriptor.Descriptor(
  name='DerivativeMarketOrder',
  full_name='injective.exchange.v1beta1.DerivativeMarketOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_info', full_name='injective.exchange.v1beta1.DerivativeMarketOrder.order_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='injective.exchange.v1beta1.DerivativeMarketOrder.order_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective.exchange.v1beta1.DerivativeMarketOrder.margin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin_hold', full_name='injective.exchange.v1beta1.DerivativeMarketOrder.margin_hold', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger_price', full_name='injective.exchange.v1beta1.DerivativeMarketOrder.trigger_price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.DerivativeMarketOrder.order_hash', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5913,
  serialized_end=6284,
)


_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='injective.exchange.v1beta1.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='isLong', full_name='injective.exchange.v1beta1.Position.isLong', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.Position.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_price', full_name='injective.exchange.v1beta1.Position.entry_price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective.exchange.v1beta1.Position.margin', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_funding_entry', full_name='injective.exchange.v1beta1.Position.cumulative_funding_entry', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6287,
  serialized_end=6594,
)


_MARKETORDERINDICATOR = _descriptor.Descriptor(
  name='MarketOrderIndicator',
  full_name='injective.exchange.v1beta1.MarketOrderIndicator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.MarketOrderIndicator.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuy', full_name='injective.exchange.v1beta1.MarketOrderIndicator.isBuy', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6596,
  serialized_end=6652,
)


_TRADELOG = _descriptor.Descriptor(
  name='TradeLog',
  full_name='injective.exchange.v1beta1.TradeLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.TradeLog.quantity', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.exchange.v1beta1.TradeLog.price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.TradeLog.subaccount_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='injective.exchange.v1beta1.TradeLog.fee', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.TradeLog.order_hash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_recipient_address', full_name='injective.exchange.v1beta1.TradeLog.fee_recipient_address', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6655,
  serialized_end=6935,
)


_POSITIONDELTA = _descriptor.Descriptor(
  name='PositionDelta',
  full_name='injective.exchange.v1beta1.PositionDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_long', full_name='injective.exchange.v1beta1.PositionDelta.is_long', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_quantity', full_name='injective.exchange.v1beta1.PositionDelta.execution_quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_margin', full_name='injective.exchange.v1beta1.PositionDelta.execution_margin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_price', full_name='injective.exchange.v1beta1.PositionDelta.execution_price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6938,
  serialized_end=7193,
)


_DERIVATIVETRADELOG = _descriptor.Descriptor(
  name='DerivativeTradeLog',
  full_name='injective.exchange.v1beta1.DerivativeTradeLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.DerivativeTradeLog.subaccount_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_delta', full_name='injective.exchange.v1beta1.DerivativeTradeLog.position_delta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payout', full_name='injective.exchange.v1beta1.DerivativeTradeLog.payout', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='injective.exchange.v1beta1.DerivativeTradeLog.fee', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.DerivativeTradeLog.order_hash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_recipient_address', full_name='injective.exchange.v1beta1.DerivativeTradeLog.fee_recipient_address', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7196,
  serialized_end=7488,
)


_EVENTBATCHSPOTEXECUTION = _descriptor.Descriptor(
  name='EventBatchSpotExecution',
  full_name='injective.exchange.v1beta1.EventBatchSpotExecution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventBatchSpotExecution.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_buy', full_name='injective.exchange.v1beta1.EventBatchSpotExecution.is_buy', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executionType', full_name='injective.exchange.v1beta1.EventBatchSpotExecution.executionType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trades', full_name='injective.exchange.v1beta1.EventBatchSpotExecution.trades', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7491,
  serialized_end=7671,
)


_EVENTBATCHDERIVATIVEEXECUTION = _descriptor.Descriptor(
  name='EventBatchDerivativeExecution',
  full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_buy', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.is_buy', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_liquidation', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.is_liquidation', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cumulative_funding', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.cumulative_funding', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executionType', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.executionType', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trades', full_name='injective.exchange.v1beta1.EventBatchDerivativeExecution.trades', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7674,
  serialized_end=7970,
)


_EVENTLOSTFUNDSFROMLIQUIDATION = _descriptor.Descriptor(
  name='EventLostFundsFromLiquidation',
  full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation.subaccount_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lost_funds_from_available_during_payout', full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation.lost_funds_from_available_during_payout', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lost_funds_from_order_cancels', full_name='injective.exchange.v1beta1.EventLostFundsFromLiquidation.lost_funds_from_order_cancels', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7973,
  serialized_end=8230,
)


_SUBACCOUNTPOSITION = _descriptor.Descriptor(
  name='SubaccountPosition',
  full_name='injective.exchange.v1beta1.SubaccountPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='position', full_name='injective.exchange.v1beta1.SubaccountPosition.position', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.SubaccountPosition.subaccount_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8232,
  serialized_end=8331,
)


_EVENTBATCHDERIVATIVEPOSITION = _descriptor.Descriptor(
  name='EventBatchDerivativePosition',
  full_name='injective.exchange.v1beta1.EventBatchDerivativePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventBatchDerivativePosition.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positions', full_name='injective.exchange.v1beta1.EventBatchDerivativePosition.positions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8333,
  serialized_end=8449,
)


_EVENTDERIVATIVEMARKETPAUSED = _descriptor.Descriptor(
  name='EventDerivativeMarketPaused',
  full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settle_price', full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused.settle_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_missing_funds', full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused.total_missing_funds', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_funds_rate', full_name='injective.exchange.v1beta1.EventDerivativeMarketPaused.missing_funds_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8451,
  serialized_end=8578,
)


_EVENTNEWSPOTORDERS = _descriptor.Descriptor(
  name='EventNewSpotOrders',
  full_name='injective.exchange.v1beta1.EventNewSpotOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventNewSpotOrders.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buy_orders', full_name='injective.exchange.v1beta1.EventNewSpotOrders.buy_orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sell_orders', full_name='injective.exchange.v1beta1.EventNewSpotOrders.sell_orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8581,
  serialized_end=8749,
)


_EVENTNEWDERIVATIVEORDERS = _descriptor.Descriptor(
  name='EventNewDerivativeOrders',
  full_name='injective.exchange.v1beta1.EventNewDerivativeOrders',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventNewDerivativeOrders.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buy_orders', full_name='injective.exchange.v1beta1.EventNewDerivativeOrders.buy_orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sell_orders', full_name='injective.exchange.v1beta1.EventNewDerivativeOrders.sell_orders', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8752,
  serialized_end=8938,
)


_EVENTCANCELSPOTORDER = _descriptor.Descriptor(
  name='EventCancelSpotOrder',
  full_name='injective.exchange.v1beta1.EventCancelSpotOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventCancelSpotOrder.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='injective.exchange.v1beta1.EventCancelSpotOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8940,
  serialized_end=9046,
)


_EVENTSPOTMARKETUPDATE = _descriptor.Descriptor(
  name='EventSpotMarketUpdate',
  full_name='injective.exchange.v1beta1.EventSpotMarketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.EventSpotMarketUpdate.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9048,
  serialized_end=9133,
)


_EVENTPERPETUALMARKETUPDATE = _descriptor.Descriptor(
  name='EventPerpetualMarketUpdate',
  full_name='injective.exchange.v1beta1.EventPerpetualMarketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.EventPerpetualMarketUpdate.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_market_info', full_name='injective.exchange.v1beta1.EventPerpetualMarketUpdate.perpetual_market_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding', full_name='injective.exchange.v1beta1.EventPerpetualMarketUpdate.funding', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9136,
  serialized_end=9393,
)


_EVENTEXPIRYFUTURESMARKETUPDATE = _descriptor.Descriptor(
  name='EventExpiryFuturesMarketUpdate',
  full_name='injective.exchange.v1beta1.EventExpiryFuturesMarketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.EventExpiryFuturesMarketUpdate.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry_futures_market_info', full_name='injective.exchange.v1beta1.EventExpiryFuturesMarketUpdate.expiry_futures_market_info', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9396,
  serialized_end=9591,
)


_EVENTPERPETUALMARKETFUNDINGUPDATE = _descriptor.Descriptor(
  name='EventPerpetualMarketFundingUpdate',
  full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.funding', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_hourly_funding', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.is_hourly_funding', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding_rate', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.funding_rate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mark_price', full_name='injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate.mark_price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9594,
  serialized_end=9888,
)


_EVENTSUBACCOUNTDEPOSIT = _descriptor.Descriptor(
  name='EventSubaccountDeposit',
  full_name='injective.exchange.v1beta1.EventSubaccountDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_address', full_name='injective.exchange.v1beta1.EventSubaccountDeposit.src_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.EventSubaccountDeposit.subaccount_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.EventSubaccountDeposit.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9890,
  serialized_end=10007,
)


_EVENTSUBACCOUNTWITHDRAW = _descriptor.Descriptor(
  name='EventSubaccountWithdraw',
  full_name='injective.exchange.v1beta1.EventSubaccountWithdraw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.EventSubaccountWithdraw.subaccount_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_address', full_name='injective.exchange.v1beta1.EventSubaccountWithdraw.dst_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.EventSubaccountWithdraw.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10009,
  serialized_end=10127,
)


_EVENTSUBACCOUNTBALANCETRANSFER = _descriptor.Descriptor(
  name='EventSubaccountBalanceTransfer',
  full_name='injective.exchange.v1beta1.EventSubaccountBalanceTransfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='src_subaccount_id', full_name='injective.exchange.v1beta1.EventSubaccountBalanceTransfer.src_subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dst_subaccount_id', full_name='injective.exchange.v1beta1.EventSubaccountBalanceTransfer.dst_subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.exchange.v1beta1.EventSubaccountBalanceTransfer.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10130,
  serialized_end=10265,
)


_SUBACCOUNTDEPOSIT = _descriptor.Descriptor(
  name='SubaccountDeposit',
  full_name='injective.exchange.v1beta1.SubaccountDeposit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.SubaccountDeposit.subaccount_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='injective.exchange.v1beta1.SubaccountDeposit.deposit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10267,
  serialized_end=10363,
)


_DEPOSITUPDATE = _descriptor.Descriptor(
  name='DepositUpdate',
  full_name='injective.exchange.v1beta1.DepositUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.exchange.v1beta1.DepositUpdate.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposits', full_name='injective.exchange.v1beta1.DepositUpdate.deposits', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10365,
  serialized_end=10460,
)


_EVENTBATCHDEPOSITUPDATE = _descriptor.Descriptor(
  name='EventBatchDepositUpdate',
  full_name='injective.exchange.v1beta1.EventBatchDepositUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposit_updates', full_name='injective.exchange.v1beta1.EventBatchDepositUpdate.deposit_updates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10462,
  serialized_end=10555,
)


_DERIVATIVEMARKETORDERCANCEL = _descriptor.Descriptor(
  name='DerivativeMarketOrderCancel',
  full_name='injective.exchange.v1beta1.DerivativeMarketOrderCancel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_order', full_name='injective.exchange.v1beta1.DerivativeMarketOrderCancel.market_order', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cancel_quantity', full_name='injective.exchange.v1beta1.DerivativeMarketOrderCancel.cancel_quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10558,
  serialized_end=10739,
)


_EVENTCANCELDERIVATIVEORDER = _descriptor.Descriptor(
  name='EventCancelDerivativeOrder',
  full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLimitCancel', full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder.isLimitCancel', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit_order', full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder.limit_order', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_order_cancel', full_name='injective.exchange.v1beta1.EventCancelDerivativeOrder.market_order_cancel', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10742,
  serialized_end=10981,
)


_POINTSMULTIPLIER = _descriptor.Descriptor(
  name='PointsMultiplier',
  full_name='injective.exchange.v1beta1.PointsMultiplier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maker_points_multiplier', full_name='injective.exchange.v1beta1.PointsMultiplier.maker_points_multiplier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_points_multiplier', full_name='injective.exchange.v1beta1.PointsMultiplier.taker_points_multiplier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10984,
  serialized_end=11164,
)


_TRADINGREWARDCAMPAIGNBOOSTINFO = _descriptor.Descriptor(
  name='TradingRewardCampaignBoostInfo',
  full_name='injective.exchange.v1beta1.TradingRewardCampaignBoostInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='boosted_spot_market_ids', full_name='injective.exchange.v1beta1.TradingRewardCampaignBoostInfo.boosted_spot_market_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_market_multipliers', full_name='injective.exchange.v1beta1.TradingRewardCampaignBoostInfo.spot_market_multipliers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boosted_derivative_market_ids', full_name='injective.exchange.v1beta1.TradingRewardCampaignBoostInfo.boosted_derivative_market_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_market_multipliers', full_name='injective.exchange.v1beta1.TradingRewardCampaignBoostInfo.derivative_market_multipliers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11167,
  serialized_end=11447,
)


_CAMPAIGNREWARDPOOL = _descriptor.Descriptor(
  name='CampaignRewardPool',
  full_name='injective.exchange.v1beta1.CampaignRewardPool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='injective.exchange.v1beta1.CampaignRewardPool.start_timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_campaign_rewards', full_name='injective.exchange.v1beta1.CampaignRewardPool.max_campaign_rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11450,
  serialized_end=11602,
)


_TRADINGREWARDCAMPAIGNINFO = _descriptor.Descriptor(
  name='TradingRewardCampaignInfo',
  full_name='injective.exchange.v1beta1.TradingRewardCampaignInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='campaign_duration_seconds', full_name='injective.exchange.v1beta1.TradingRewardCampaignInfo.campaign_duration_seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denoms', full_name='injective.exchange.v1beta1.TradingRewardCampaignInfo.quote_denoms', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_boost_info', full_name='injective.exchange.v1beta1.TradingRewardCampaignInfo.trading_reward_boost_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disqualified_market_ids', full_name='injective.exchange.v1beta1.TradingRewardCampaignInfo.disqualified_market_ids', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11605,
  serialized_end=11817,
)


_FEEDISCOUNTTIERINFO = _descriptor.Descriptor(
  name='FeeDiscountTierInfo',
  full_name='injective.exchange.v1beta1.FeeDiscountTierInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maker_discount_rate', full_name='injective.exchange.v1beta1.FeeDiscountTierInfo.maker_discount_rate', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taker_discount_rate', full_name='injective.exchange.v1beta1.FeeDiscountTierInfo.taker_discount_rate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='staked_amount', full_name='injective.exchange.v1beta1.FeeDiscountTierInfo.staked_amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_paid_amount', full_name='injective.exchange.v1beta1.FeeDiscountTierInfo.fee_paid_amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11820,
  serialized_end=12139,
)


_FEEDISCOUNTSCHEDULE = _descriptor.Descriptor(
  name='FeeDiscountSchedule',
  full_name='injective.exchange.v1beta1.FeeDiscountSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket_count', full_name='injective.exchange.v1beta1.FeeDiscountSchedule.bucket_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_duration', full_name='injective.exchange.v1beta1.FeeDiscountSchedule.bucket_duration', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denoms', full_name='injective.exchange.v1beta1.FeeDiscountSchedule.quote_denoms', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tier_infos', full_name='injective.exchange.v1beta1.FeeDiscountSchedule.tier_infos', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disqualified_market_ids', full_name='injective.exchange.v1beta1.FeeDiscountSchedule.disqualified_market_ids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12142,
  serialized_end=12334,
)


_FEEDISCOUNTTIERTTL = _descriptor.Descriptor(
  name='FeeDiscountTierTTL',
  full_name='injective.exchange.v1beta1.FeeDiscountTierTTL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tier', full_name='injective.exchange.v1beta1.FeeDiscountTierTTL.tier', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_timestamp', full_name='injective.exchange.v1beta1.FeeDiscountTierTTL.ttl_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12336,
  serialized_end=12393,
)


_EVENTFEEDISCOUNTSCHEDULE = _descriptor.Descriptor(
  name='EventFeeDiscountSchedule',
  full_name='injective.exchange.v1beta1.EventFeeDiscountSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schedule', full_name='injective.exchange.v1beta1.EventFeeDiscountSchedule.schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12395,
  serialized_end=12488,
)


_EVENTTRADINGREWARDCAMPAIGNUPDATE = _descriptor.Descriptor(
  name='EventTradingRewardCampaignUpdate',
  full_name='injective.exchange.v1beta1.EventTradingRewardCampaignUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='campaign_info', full_name='injective.exchange.v1beta1.EventTradingRewardCampaignUpdate.campaign_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='campaign_reward_pools', full_name='injective.exchange.v1beta1.EventTradingRewardCampaignUpdate.campaign_reward_pools', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12491,
  serialized_end=12682,
)


_ACCOUNTREWARDS = _descriptor.Descriptor(
  name='AccountRewards',
  full_name='injective.exchange.v1beta1.AccountRewards',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.AccountRewards.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='injective.exchange.v1beta1.AccountRewards.rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12684,
  serialized_end=12811,
)


_EVENTTRADINGREWARDDISTRIBUTION = _descriptor.Descriptor(
  name='EventTradingRewardDistribution',
  full_name='injective.exchange.v1beta1.EventTradingRewardDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_rewards', full_name='injective.exchange.v1beta1.EventTradingRewardDistribution.account_rewards', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12813,
  serialized_end=12914,
)

_PARAMS.fields_by_name['spot_market_instant_listing_fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_PARAMS.fields_by_name['derivative_market_instant_listing_fee'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_DERIVATIVEMARKET.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_DERIVATIVEMARKET.fields_by_name['status'].enum_type = _MARKETSTATUS
_SPOTMARKET.fields_by_name['status'].enum_type = _MARKETSTATUS
_SPOTORDER.fields_by_name['order_info'].message_type = _ORDERINFO
_SPOTORDER.fields_by_name['order_type'].enum_type = _ORDERTYPE
_SPOTLIMITORDER.fields_by_name['order_info'].message_type = _ORDERINFO
_SPOTLIMITORDER.fields_by_name['order_type'].enum_type = _ORDERTYPE
_SPOTMARKETORDER.fields_by_name['order_info'].message_type = _ORDERINFO
_DERIVATIVEORDER.fields_by_name['order_info'].message_type = _ORDERINFO
_DERIVATIVEORDER.fields_by_name['order_type'].enum_type = _ORDERTYPE
_DERIVATIVELIMITORDER.fields_by_name['order_info'].message_type = _ORDERINFO
_DERIVATIVELIMITORDER.fields_by_name['order_type'].enum_type = _ORDERTYPE
_DERIVATIVEMARKETORDER.fields_by_name['order_info'].message_type = _ORDERINFO
_DERIVATIVEMARKETORDER.fields_by_name['order_type'].enum_type = _ORDERTYPE
_DERIVATIVETRADELOG.fields_by_name['position_delta'].message_type = _POSITIONDELTA
_EVENTBATCHSPOTEXECUTION.fields_by_name['executionType'].enum_type = _EXECUTIONTYPE
_EVENTBATCHSPOTEXECUTION.fields_by_name['trades'].message_type = _TRADELOG
_EVENTBATCHDERIVATIVEEXECUTION.fields_by_name['executionType'].enum_type = _EXECUTIONTYPE
_EVENTBATCHDERIVATIVEEXECUTION.fields_by_name['trades'].message_type = _DERIVATIVETRADELOG
_SUBACCOUNTPOSITION.fields_by_name['position'].message_type = _POSITION
_EVENTBATCHDERIVATIVEPOSITION.fields_by_name['positions'].message_type = _SUBACCOUNTPOSITION
_EVENTNEWSPOTORDERS.fields_by_name['buy_orders'].message_type = _SPOTLIMITORDER
_EVENTNEWSPOTORDERS.fields_by_name['sell_orders'].message_type = _SPOTLIMITORDER
_EVENTNEWDERIVATIVEORDERS.fields_by_name['buy_orders'].message_type = _DERIVATIVELIMITORDER
_EVENTNEWDERIVATIVEORDERS.fields_by_name['sell_orders'].message_type = _DERIVATIVELIMITORDER
_EVENTCANCELSPOTORDER.fields_by_name['order'].message_type = _SPOTLIMITORDER
_EVENTSPOTMARKETUPDATE.fields_by_name['market'].message_type = _SPOTMARKET
_EVENTPERPETUALMARKETUPDATE.fields_by_name['market'].message_type = _DERIVATIVEMARKET
_EVENTPERPETUALMARKETUPDATE.fields_by_name['perpetual_market_info'].message_type = _PERPETUALMARKETINFO
_EVENTPERPETUALMARKETUPDATE.fields_by_name['funding'].message_type = _PERPETUALMARKETFUNDING
_EVENTEXPIRYFUTURESMARKETUPDATE.fields_by_name['market'].message_type = _DERIVATIVEMARKET
_EVENTEXPIRYFUTURESMARKETUPDATE.fields_by_name['expiry_futures_market_info'].message_type = _EXPIRYFUTURESMARKETINFO
_EVENTPERPETUALMARKETFUNDINGUPDATE.fields_by_name['funding'].message_type = _PERPETUALMARKETFUNDING
_EVENTSUBACCOUNTDEPOSIT.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTSUBACCOUNTWITHDRAW.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTSUBACCOUNTBALANCETRANSFER.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_SUBACCOUNTDEPOSIT.fields_by_name['deposit'].message_type = _DEPOSIT
_DEPOSITUPDATE.fields_by_name['deposits'].message_type = _SUBACCOUNTDEPOSIT
_EVENTBATCHDEPOSITUPDATE.fields_by_name['deposit_updates'].message_type = _DEPOSITUPDATE
_DERIVATIVEMARKETORDERCANCEL.fields_by_name['market_order'].message_type = _DERIVATIVEMARKETORDER
_EVENTCANCELDERIVATIVEORDER.fields_by_name['limit_order'].message_type = _DERIVATIVELIMITORDER
_EVENTCANCELDERIVATIVEORDER.fields_by_name['market_order_cancel'].message_type = _DERIVATIVEMARKETORDERCANCEL
_TRADINGREWARDCAMPAIGNBOOSTINFO.fields_by_name['spot_market_multipliers'].message_type = _POINTSMULTIPLIER
_TRADINGREWARDCAMPAIGNBOOSTINFO.fields_by_name['derivative_market_multipliers'].message_type = _POINTSMULTIPLIER
_CAMPAIGNREWARDPOOL.fields_by_name['max_campaign_rewards'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_TRADINGREWARDCAMPAIGNINFO.fields_by_name['trading_reward_boost_info'].message_type = _TRADINGREWARDCAMPAIGNBOOSTINFO
_FEEDISCOUNTSCHEDULE.fields_by_name['tier_infos'].message_type = _FEEDISCOUNTTIERINFO
_EVENTFEEDISCOUNTSCHEDULE.fields_by_name['schedule'].message_type = _FEEDISCOUNTSCHEDULE
_EVENTTRADINGREWARDCAMPAIGNUPDATE.fields_by_name['campaign_info'].message_type = _TRADINGREWARDCAMPAIGNINFO
_EVENTTRADINGREWARDCAMPAIGNUPDATE.fields_by_name['campaign_reward_pools'].message_type = _CAMPAIGNREWARDPOOL
_ACCOUNTREWARDS.fields_by_name['rewards'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_EVENTTRADINGREWARDDISTRIBUTION.fields_by_name['account_rewards'].message_type = _ACCOUNTREWARDS
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['DerivativeMarket'] = _DERIVATIVEMARKET
DESCRIPTOR.message_types_by_name['ExpiryFuturesMarketInfo'] = _EXPIRYFUTURESMARKETINFO
DESCRIPTOR.message_types_by_name['PerpetualMarketInfo'] = _PERPETUALMARKETINFO
DESCRIPTOR.message_types_by_name['PerpetualMarketFunding'] = _PERPETUALMARKETFUNDING
DESCRIPTOR.message_types_by_name['DerivativeMarketSettlementInfo'] = _DERIVATIVEMARKETSETTLEMENTINFO
DESCRIPTOR.message_types_by_name['NextFundingTimestamp'] = _NEXTFUNDINGTIMESTAMP
DESCRIPTOR.message_types_by_name['SpotMarket'] = _SPOTMARKET
DESCRIPTOR.message_types_by_name['Deposit'] = _DEPOSIT
DESCRIPTOR.message_types_by_name['SubaccountTradeNonce'] = _SUBACCOUNTTRADENONCE
DESCRIPTOR.message_types_by_name['OrderInfo'] = _ORDERINFO
DESCRIPTOR.message_types_by_name['SpotOrder'] = _SPOTORDER
DESCRIPTOR.message_types_by_name['SpotLimitOrder'] = _SPOTLIMITORDER
DESCRIPTOR.message_types_by_name['SpotMarketOrder'] = _SPOTMARKETORDER
DESCRIPTOR.message_types_by_name['DerivativeOrder'] = _DERIVATIVEORDER
DESCRIPTOR.message_types_by_name['SubaccountOrderbookMetadata'] = _SUBACCOUNTORDERBOOKMETADATA
DESCRIPTOR.message_types_by_name['SubaccountOrder'] = _SUBACCOUNTORDER
DESCRIPTOR.message_types_by_name['DerivativeLimitOrder'] = _DERIVATIVELIMITORDER
DESCRIPTOR.message_types_by_name['DerivativeMarketOrder'] = _DERIVATIVEMARKETORDER
DESCRIPTOR.message_types_by_name['Position'] = _POSITION
DESCRIPTOR.message_types_by_name['MarketOrderIndicator'] = _MARKETORDERINDICATOR
DESCRIPTOR.message_types_by_name['TradeLog'] = _TRADELOG
DESCRIPTOR.message_types_by_name['PositionDelta'] = _POSITIONDELTA
DESCRIPTOR.message_types_by_name['DerivativeTradeLog'] = _DERIVATIVETRADELOG
DESCRIPTOR.message_types_by_name['EventBatchSpotExecution'] = _EVENTBATCHSPOTEXECUTION
DESCRIPTOR.message_types_by_name['EventBatchDerivativeExecution'] = _EVENTBATCHDERIVATIVEEXECUTION
DESCRIPTOR.message_types_by_name['EventLostFundsFromLiquidation'] = _EVENTLOSTFUNDSFROMLIQUIDATION
DESCRIPTOR.message_types_by_name['SubaccountPosition'] = _SUBACCOUNTPOSITION
DESCRIPTOR.message_types_by_name['EventBatchDerivativePosition'] = _EVENTBATCHDERIVATIVEPOSITION
DESCRIPTOR.message_types_by_name['EventDerivativeMarketPaused'] = _EVENTDERIVATIVEMARKETPAUSED
DESCRIPTOR.message_types_by_name['EventNewSpotOrders'] = _EVENTNEWSPOTORDERS
DESCRIPTOR.message_types_by_name['EventNewDerivativeOrders'] = _EVENTNEWDERIVATIVEORDERS
DESCRIPTOR.message_types_by_name['EventCancelSpotOrder'] = _EVENTCANCELSPOTORDER
DESCRIPTOR.message_types_by_name['EventSpotMarketUpdate'] = _EVENTSPOTMARKETUPDATE
DESCRIPTOR.message_types_by_name['EventPerpetualMarketUpdate'] = _EVENTPERPETUALMARKETUPDATE
DESCRIPTOR.message_types_by_name['EventExpiryFuturesMarketUpdate'] = _EVENTEXPIRYFUTURESMARKETUPDATE
DESCRIPTOR.message_types_by_name['EventPerpetualMarketFundingUpdate'] = _EVENTPERPETUALMARKETFUNDINGUPDATE
DESCRIPTOR.message_types_by_name['EventSubaccountDeposit'] = _EVENTSUBACCOUNTDEPOSIT
DESCRIPTOR.message_types_by_name['EventSubaccountWithdraw'] = _EVENTSUBACCOUNTWITHDRAW
DESCRIPTOR.message_types_by_name['EventSubaccountBalanceTransfer'] = _EVENTSUBACCOUNTBALANCETRANSFER
DESCRIPTOR.message_types_by_name['SubaccountDeposit'] = _SUBACCOUNTDEPOSIT
DESCRIPTOR.message_types_by_name['DepositUpdate'] = _DEPOSITUPDATE
DESCRIPTOR.message_types_by_name['EventBatchDepositUpdate'] = _EVENTBATCHDEPOSITUPDATE
DESCRIPTOR.message_types_by_name['DerivativeMarketOrderCancel'] = _DERIVATIVEMARKETORDERCANCEL
DESCRIPTOR.message_types_by_name['EventCancelDerivativeOrder'] = _EVENTCANCELDERIVATIVEORDER
DESCRIPTOR.message_types_by_name['PointsMultiplier'] = _POINTSMULTIPLIER
DESCRIPTOR.message_types_by_name['TradingRewardCampaignBoostInfo'] = _TRADINGREWARDCAMPAIGNBOOSTINFO
DESCRIPTOR.message_types_by_name['CampaignRewardPool'] = _CAMPAIGNREWARDPOOL
DESCRIPTOR.message_types_by_name['TradingRewardCampaignInfo'] = _TRADINGREWARDCAMPAIGNINFO
DESCRIPTOR.message_types_by_name['FeeDiscountTierInfo'] = _FEEDISCOUNTTIERINFO
DESCRIPTOR.message_types_by_name['FeeDiscountSchedule'] = _FEEDISCOUNTSCHEDULE
DESCRIPTOR.message_types_by_name['FeeDiscountTierTTL'] = _FEEDISCOUNTTIERTTL
DESCRIPTOR.message_types_by_name['EventFeeDiscountSchedule'] = _EVENTFEEDISCOUNTSCHEDULE
DESCRIPTOR.message_types_by_name['EventTradingRewardCampaignUpdate'] = _EVENTTRADINGREWARDCAMPAIGNUPDATE
DESCRIPTOR.message_types_by_name['AccountRewards'] = _ACCOUNTREWARDS
DESCRIPTOR.message_types_by_name['EventTradingRewardDistribution'] = _EVENTTRADINGREWARDDISTRIBUTION
DESCRIPTOR.enum_types_by_name['MarketStatus'] = _MARKETSTATUS
DESCRIPTOR.enum_types_by_name['OrderType'] = _ORDERTYPE
DESCRIPTOR.enum_types_by_name['ExecutionType'] = _EXECUTIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

DerivativeMarket = _reflection.GeneratedProtocolMessageType('DerivativeMarket', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEMARKET,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeMarket)
  })
_sym_db.RegisterMessage(DerivativeMarket)

ExpiryFuturesMarketInfo = _reflection.GeneratedProtocolMessageType('ExpiryFuturesMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXPIRYFUTURESMARKETINFO,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.ExpiryFuturesMarketInfo)
  })
_sym_db.RegisterMessage(ExpiryFuturesMarketInfo)

PerpetualMarketInfo = _reflection.GeneratedProtocolMessageType('PerpetualMarketInfo', (_message.Message,), {
  'DESCRIPTOR' : _PERPETUALMARKETINFO,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PerpetualMarketInfo)
  })
_sym_db.RegisterMessage(PerpetualMarketInfo)

PerpetualMarketFunding = _reflection.GeneratedProtocolMessageType('PerpetualMarketFunding', (_message.Message,), {
  'DESCRIPTOR' : _PERPETUALMARKETFUNDING,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PerpetualMarketFunding)
  })
_sym_db.RegisterMessage(PerpetualMarketFunding)

DerivativeMarketSettlementInfo = _reflection.GeneratedProtocolMessageType('DerivativeMarketSettlementInfo', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEMARKETSETTLEMENTINFO,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeMarketSettlementInfo)
  })
_sym_db.RegisterMessage(DerivativeMarketSettlementInfo)

NextFundingTimestamp = _reflection.GeneratedProtocolMessageType('NextFundingTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _NEXTFUNDINGTIMESTAMP,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.NextFundingTimestamp)
  })
_sym_db.RegisterMessage(NextFundingTimestamp)

SpotMarket = _reflection.GeneratedProtocolMessageType('SpotMarket', (_message.Message,), {
  'DESCRIPTOR' : _SPOTMARKET,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SpotMarket)
  })
_sym_db.RegisterMessage(SpotMarket)

Deposit = _reflection.GeneratedProtocolMessageType('Deposit', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSIT,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.Deposit)
  })
_sym_db.RegisterMessage(Deposit)

SubaccountTradeNonce = _reflection.GeneratedProtocolMessageType('SubaccountTradeNonce', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTTRADENONCE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SubaccountTradeNonce)
  })
_sym_db.RegisterMessage(SubaccountTradeNonce)

OrderInfo = _reflection.GeneratedProtocolMessageType('OrderInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORDERINFO,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.OrderInfo)
  })
_sym_db.RegisterMessage(OrderInfo)

SpotOrder = _reflection.GeneratedProtocolMessageType('SpotOrder', (_message.Message,), {
  'DESCRIPTOR' : _SPOTORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SpotOrder)
  })
_sym_db.RegisterMessage(SpotOrder)

SpotLimitOrder = _reflection.GeneratedProtocolMessageType('SpotLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _SPOTLIMITORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SpotLimitOrder)
  })
_sym_db.RegisterMessage(SpotLimitOrder)

SpotMarketOrder = _reflection.GeneratedProtocolMessageType('SpotMarketOrder', (_message.Message,), {
  'DESCRIPTOR' : _SPOTMARKETORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SpotMarketOrder)
  })
_sym_db.RegisterMessage(SpotMarketOrder)

DerivativeOrder = _reflection.GeneratedProtocolMessageType('DerivativeOrder', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeOrder)
  })
_sym_db.RegisterMessage(DerivativeOrder)

SubaccountOrderbookMetadata = _reflection.GeneratedProtocolMessageType('SubaccountOrderbookMetadata', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDERBOOKMETADATA,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SubaccountOrderbookMetadata)
  })
_sym_db.RegisterMessage(SubaccountOrderbookMetadata)

SubaccountOrder = _reflection.GeneratedProtocolMessageType('SubaccountOrder', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SubaccountOrder)
  })
_sym_db.RegisterMessage(SubaccountOrder)

DerivativeLimitOrder = _reflection.GeneratedProtocolMessageType('DerivativeLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVELIMITORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeLimitOrder)
  })
_sym_db.RegisterMessage(DerivativeLimitOrder)

DerivativeMarketOrder = _reflection.GeneratedProtocolMessageType('DerivativeMarketOrder', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEMARKETORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeMarketOrder)
  })
_sym_db.RegisterMessage(DerivativeMarketOrder)

Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), {
  'DESCRIPTOR' : _POSITION,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.Position)
  })
_sym_db.RegisterMessage(Position)

MarketOrderIndicator = _reflection.GeneratedProtocolMessageType('MarketOrderIndicator', (_message.Message,), {
  'DESCRIPTOR' : _MARKETORDERINDICATOR,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.MarketOrderIndicator)
  })
_sym_db.RegisterMessage(MarketOrderIndicator)

TradeLog = _reflection.GeneratedProtocolMessageType('TradeLog', (_message.Message,), {
  'DESCRIPTOR' : _TRADELOG,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradeLog)
  })
_sym_db.RegisterMessage(TradeLog)

PositionDelta = _reflection.GeneratedProtocolMessageType('PositionDelta', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONDELTA,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PositionDelta)
  })
_sym_db.RegisterMessage(PositionDelta)

DerivativeTradeLog = _reflection.GeneratedProtocolMessageType('DerivativeTradeLog', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVETRADELOG,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeTradeLog)
  })
_sym_db.RegisterMessage(DerivativeTradeLog)

EventBatchSpotExecution = _reflection.GeneratedProtocolMessageType('EventBatchSpotExecution', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCHSPOTEXECUTION,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBatchSpotExecution)
  })
_sym_db.RegisterMessage(EventBatchSpotExecution)

EventBatchDerivativeExecution = _reflection.GeneratedProtocolMessageType('EventBatchDerivativeExecution', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCHDERIVATIVEEXECUTION,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBatchDerivativeExecution)
  })
_sym_db.RegisterMessage(EventBatchDerivativeExecution)

EventLostFundsFromLiquidation = _reflection.GeneratedProtocolMessageType('EventLostFundsFromLiquidation', (_message.Message,), {
  'DESCRIPTOR' : _EVENTLOSTFUNDSFROMLIQUIDATION,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventLostFundsFromLiquidation)
  })
_sym_db.RegisterMessage(EventLostFundsFromLiquidation)

SubaccountPosition = _reflection.GeneratedProtocolMessageType('SubaccountPosition', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTPOSITION,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SubaccountPosition)
  })
_sym_db.RegisterMessage(SubaccountPosition)

EventBatchDerivativePosition = _reflection.GeneratedProtocolMessageType('EventBatchDerivativePosition', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCHDERIVATIVEPOSITION,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBatchDerivativePosition)
  })
_sym_db.RegisterMessage(EventBatchDerivativePosition)

EventDerivativeMarketPaused = _reflection.GeneratedProtocolMessageType('EventDerivativeMarketPaused', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDERIVATIVEMARKETPAUSED,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventDerivativeMarketPaused)
  })
_sym_db.RegisterMessage(EventDerivativeMarketPaused)

EventNewSpotOrders = _reflection.GeneratedProtocolMessageType('EventNewSpotOrders', (_message.Message,), {
  'DESCRIPTOR' : _EVENTNEWSPOTORDERS,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventNewSpotOrders)
  })
_sym_db.RegisterMessage(EventNewSpotOrders)

EventNewDerivativeOrders = _reflection.GeneratedProtocolMessageType('EventNewDerivativeOrders', (_message.Message,), {
  'DESCRIPTOR' : _EVENTNEWDERIVATIVEORDERS,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventNewDerivativeOrders)
  })
_sym_db.RegisterMessage(EventNewDerivativeOrders)

EventCancelSpotOrder = _reflection.GeneratedProtocolMessageType('EventCancelSpotOrder', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCANCELSPOTORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventCancelSpotOrder)
  })
_sym_db.RegisterMessage(EventCancelSpotOrder)

EventSpotMarketUpdate = _reflection.GeneratedProtocolMessageType('EventSpotMarketUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSPOTMARKETUPDATE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventSpotMarketUpdate)
  })
_sym_db.RegisterMessage(EventSpotMarketUpdate)

EventPerpetualMarketUpdate = _reflection.GeneratedProtocolMessageType('EventPerpetualMarketUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTPERPETUALMARKETUPDATE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventPerpetualMarketUpdate)
  })
_sym_db.RegisterMessage(EventPerpetualMarketUpdate)

EventExpiryFuturesMarketUpdate = _reflection.GeneratedProtocolMessageType('EventExpiryFuturesMarketUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTEXPIRYFUTURESMARKETUPDATE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventExpiryFuturesMarketUpdate)
  })
_sym_db.RegisterMessage(EventExpiryFuturesMarketUpdate)

EventPerpetualMarketFundingUpdate = _reflection.GeneratedProtocolMessageType('EventPerpetualMarketFundingUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTPERPETUALMARKETFUNDINGUPDATE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventPerpetualMarketFundingUpdate)
  })
_sym_db.RegisterMessage(EventPerpetualMarketFundingUpdate)

EventSubaccountDeposit = _reflection.GeneratedProtocolMessageType('EventSubaccountDeposit', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBACCOUNTDEPOSIT,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventSubaccountDeposit)
  })
_sym_db.RegisterMessage(EventSubaccountDeposit)

EventSubaccountWithdraw = _reflection.GeneratedProtocolMessageType('EventSubaccountWithdraw', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBACCOUNTWITHDRAW,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventSubaccountWithdraw)
  })
_sym_db.RegisterMessage(EventSubaccountWithdraw)

EventSubaccountBalanceTransfer = _reflection.GeneratedProtocolMessageType('EventSubaccountBalanceTransfer', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBACCOUNTBALANCETRANSFER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventSubaccountBalanceTransfer)
  })
_sym_db.RegisterMessage(EventSubaccountBalanceTransfer)

SubaccountDeposit = _reflection.GeneratedProtocolMessageType('SubaccountDeposit', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTDEPOSIT,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SubaccountDeposit)
  })
_sym_db.RegisterMessage(SubaccountDeposit)

DepositUpdate = _reflection.GeneratedProtocolMessageType('DepositUpdate', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSITUPDATE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DepositUpdate)
  })
_sym_db.RegisterMessage(DepositUpdate)

EventBatchDepositUpdate = _reflection.GeneratedProtocolMessageType('EventBatchDepositUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBATCHDEPOSITUPDATE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventBatchDepositUpdate)
  })
_sym_db.RegisterMessage(EventBatchDepositUpdate)

DerivativeMarketOrderCancel = _reflection.GeneratedProtocolMessageType('DerivativeMarketOrderCancel', (_message.Message,), {
  'DESCRIPTOR' : _DERIVATIVEMARKETORDERCANCEL,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.DerivativeMarketOrderCancel)
  })
_sym_db.RegisterMessage(DerivativeMarketOrderCancel)

EventCancelDerivativeOrder = _reflection.GeneratedProtocolMessageType('EventCancelDerivativeOrder', (_message.Message,), {
  'DESCRIPTOR' : _EVENTCANCELDERIVATIVEORDER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventCancelDerivativeOrder)
  })
_sym_db.RegisterMessage(EventCancelDerivativeOrder)

PointsMultiplier = _reflection.GeneratedProtocolMessageType('PointsMultiplier', (_message.Message,), {
  'DESCRIPTOR' : _POINTSMULTIPLIER,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PointsMultiplier)
  })
_sym_db.RegisterMessage(PointsMultiplier)

TradingRewardCampaignBoostInfo = _reflection.GeneratedProtocolMessageType('TradingRewardCampaignBoostInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDCAMPAIGNBOOSTINFO,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardCampaignBoostInfo)
  })
_sym_db.RegisterMessage(TradingRewardCampaignBoostInfo)

CampaignRewardPool = _reflection.GeneratedProtocolMessageType('CampaignRewardPool', (_message.Message,), {
  'DESCRIPTOR' : _CAMPAIGNREWARDPOOL,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.CampaignRewardPool)
  })
_sym_db.RegisterMessage(CampaignRewardPool)

TradingRewardCampaignInfo = _reflection.GeneratedProtocolMessageType('TradingRewardCampaignInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRADINGREWARDCAMPAIGNINFO,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradingRewardCampaignInfo)
  })
_sym_db.RegisterMessage(TradingRewardCampaignInfo)

FeeDiscountTierInfo = _reflection.GeneratedProtocolMessageType('FeeDiscountTierInfo', (_message.Message,), {
  'DESCRIPTOR' : _FEEDISCOUNTTIERINFO,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FeeDiscountTierInfo)
  })
_sym_db.RegisterMessage(FeeDiscountTierInfo)

FeeDiscountSchedule = _reflection.GeneratedProtocolMessageType('FeeDiscountSchedule', (_message.Message,), {
  'DESCRIPTOR' : _FEEDISCOUNTSCHEDULE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FeeDiscountSchedule)
  })
_sym_db.RegisterMessage(FeeDiscountSchedule)

FeeDiscountTierTTL = _reflection.GeneratedProtocolMessageType('FeeDiscountTierTTL', (_message.Message,), {
  'DESCRIPTOR' : _FEEDISCOUNTTIERTTL,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FeeDiscountTierTTL)
  })
_sym_db.RegisterMessage(FeeDiscountTierTTL)

EventFeeDiscountSchedule = _reflection.GeneratedProtocolMessageType('EventFeeDiscountSchedule', (_message.Message,), {
  'DESCRIPTOR' : _EVENTFEEDISCOUNTSCHEDULE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventFeeDiscountSchedule)
  })
_sym_db.RegisterMessage(EventFeeDiscountSchedule)

EventTradingRewardCampaignUpdate = _reflection.GeneratedProtocolMessageType('EventTradingRewardCampaignUpdate', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTRADINGREWARDCAMPAIGNUPDATE,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventTradingRewardCampaignUpdate)
  })
_sym_db.RegisterMessage(EventTradingRewardCampaignUpdate)

AccountRewards = _reflection.GeneratedProtocolMessageType('AccountRewards', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTREWARDS,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.AccountRewards)
  })
_sym_db.RegisterMessage(AccountRewards)

EventTradingRewardDistribution = _reflection.GeneratedProtocolMessageType('EventTradingRewardDistribution', (_message.Message,), {
  'DESCRIPTOR' : _EVENTTRADINGREWARDDISTRIBUTION,
  '__module__' : 'injective.exchange.v1beta1.exchange_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EventTradingRewardDistribution)
  })
_sym_db.RegisterMessage(EventTradingRewardDistribution)


DESCRIPTOR._options = None
_ORDERTYPE.values_by_name["UNSPECIFIED"]._options = None
_ORDERTYPE.values_by_name["BUY"]._options = None
_ORDERTYPE.values_by_name["SELL"]._options = None
_ORDERTYPE.values_by_name["STOP_BUY"]._options = None
_ORDERTYPE.values_by_name["STOP_SELL"]._options = None
_ORDERTYPE.values_by_name["TAKE_BUY"]._options = None
_ORDERTYPE.values_by_name["TAKE_SELL"]._options = None
_ORDERTYPE.values_by_name["BUY_PO"]._options = None
_ORDERTYPE.values_by_name["SELL_PO"]._options = None
_PARAMS.fields_by_name['spot_market_instant_listing_fee']._options = None
_PARAMS.fields_by_name['derivative_market_instant_listing_fee']._options = None
_PARAMS.fields_by_name['default_spot_maker_fee_rate']._options = None
_PARAMS.fields_by_name['default_spot_taker_fee_rate']._options = None
_PARAMS.fields_by_name['default_derivative_maker_fee_rate']._options = None
_PARAMS.fields_by_name['default_derivative_taker_fee_rate']._options = None
_PARAMS.fields_by_name['default_initial_margin_ratio']._options = None
_PARAMS.fields_by_name['default_maintenance_margin_ratio']._options = None
_PARAMS.fields_by_name['relayer_fee_share_rate']._options = None
_PARAMS.fields_by_name['default_hourly_funding_rate_cap']._options = None
_PARAMS.fields_by_name['default_hourly_interest_rate']._options = None
_PARAMS.fields_by_name['inj_reward_staked_requirement_threshold']._options = None
_PARAMS._options = None
_DERIVATIVEMARKET.fields_by_name['initial_margin_ratio']._options = None
_DERIVATIVEMARKET.fields_by_name['maintenance_margin_ratio']._options = None
_DERIVATIVEMARKET.fields_by_name['maker_fee_rate']._options = None
_DERIVATIVEMARKET.fields_by_name['taker_fee_rate']._options = None
_DERIVATIVEMARKET.fields_by_name['relayer_fee_share_rate']._options = None
_DERIVATIVEMARKET.fields_by_name['min_price_tick_size']._options = None
_DERIVATIVEMARKET.fields_by_name['min_quantity_tick_size']._options = None
_EXPIRYFUTURESMARKETINFO.fields_by_name['expiration_twap_start_price_cumulative']._options = None
_EXPIRYFUTURESMARKETINFO.fields_by_name['settlement_price']._options = None
_PERPETUALMARKETINFO.fields_by_name['hourly_funding_rate_cap']._options = None
_PERPETUALMARKETINFO.fields_by_name['hourly_interest_rate']._options = None
_PERPETUALMARKETFUNDING.fields_by_name['cumulative_funding']._options = None
_PERPETUALMARKETFUNDING.fields_by_name['cumulative_price']._options = None
_DERIVATIVEMARKETSETTLEMENTINFO.fields_by_name['settlement_price']._options = None
_DERIVATIVEMARKETSETTLEMENTINFO.fields_by_name['starting_deficit']._options = None
_SPOTMARKET.fields_by_name['maker_fee_rate']._options = None
_SPOTMARKET.fields_by_name['taker_fee_rate']._options = None
_SPOTMARKET.fields_by_name['relayer_fee_share_rate']._options = None
_SPOTMARKET.fields_by_name['min_price_tick_size']._options = None
_SPOTMARKET.fields_by_name['min_quantity_tick_size']._options = None
_DEPOSIT.fields_by_name['available_balance']._options = None
_DEPOSIT.fields_by_name['total_balance']._options = None
_ORDERINFO.fields_by_name['price']._options = None
_ORDERINFO.fields_by_name['quantity']._options = None
_SPOTORDER.fields_by_name['order_info']._options = None
_SPOTORDER.fields_by_name['trigger_price']._options = None
_SPOTLIMITORDER.fields_by_name['order_info']._options = None
_SPOTLIMITORDER.fields_by_name['fillable']._options = None
_SPOTLIMITORDER.fields_by_name['trigger_price']._options = None
_SPOTMARKETORDER.fields_by_name['order_info']._options = None
_SPOTMARKETORDER.fields_by_name['balance_hold']._options = None
_DERIVATIVEORDER.fields_by_name['order_info']._options = None
_DERIVATIVEORDER.fields_by_name['margin']._options = None
_DERIVATIVEORDER.fields_by_name['trigger_price']._options = None
_SUBACCOUNTORDERBOOKMETADATA.fields_by_name['aggregate_reduce_only_quantity']._options = None
_SUBACCOUNTORDERBOOKMETADATA.fields_by_name['aggregate_vanilla_quantity']._options = None
_SUBACCOUNTORDER.fields_by_name['price']._options = None
_SUBACCOUNTORDER.fields_by_name['quantity']._options = None
_DERIVATIVELIMITORDER.fields_by_name['order_info']._options = None
_DERIVATIVELIMITORDER.fields_by_name['margin']._options = None
_DERIVATIVELIMITORDER.fields_by_name['fillable']._options = None
_DERIVATIVELIMITORDER.fields_by_name['trigger_price']._options = None
_DERIVATIVEMARKETORDER.fields_by_name['order_info']._options = None
_DERIVATIVEMARKETORDER.fields_by_name['margin']._options = None
_DERIVATIVEMARKETORDER.fields_by_name['margin_hold']._options = None
_DERIVATIVEMARKETORDER.fields_by_name['trigger_price']._options = None
_POSITION.fields_by_name['quantity']._options = None
_POSITION.fields_by_name['entry_price']._options = None
_POSITION.fields_by_name['margin']._options = None
_POSITION.fields_by_name['cumulative_funding_entry']._options = None
_TRADELOG.fields_by_name['quantity']._options = None
_TRADELOG.fields_by_name['price']._options = None
_TRADELOG.fields_by_name['fee']._options = None
_TRADELOG.fields_by_name['fee_recipient_address']._options = None
_POSITIONDELTA.fields_by_name['execution_quantity']._options = None
_POSITIONDELTA.fields_by_name['execution_margin']._options = None
_POSITIONDELTA.fields_by_name['execution_price']._options = None
_DERIVATIVETRADELOG.fields_by_name['payout']._options = None
_DERIVATIVETRADELOG.fields_by_name['fee']._options = None
_DERIVATIVETRADELOG.fields_by_name['fee_recipient_address']._options = None
_EVENTBATCHDERIVATIVEEXECUTION.fields_by_name['cumulative_funding']._options = None
_EVENTLOSTFUNDSFROMLIQUIDATION.fields_by_name['lost_funds_from_available_during_payout']._options = None
_EVENTLOSTFUNDSFROMLIQUIDATION.fields_by_name['lost_funds_from_order_cancels']._options = None
_EVENTCANCELSPOTORDER.fields_by_name['order']._options = None
_EVENTSPOTMARKETUPDATE.fields_by_name['market']._options = None
_EVENTPERPETUALMARKETUPDATE.fields_by_name['market']._options = None
_EVENTPERPETUALMARKETUPDATE.fields_by_name['perpetual_market_info']._options = None
_EVENTPERPETUALMARKETUPDATE.fields_by_name['funding']._options = None
_EVENTEXPIRYFUTURESMARKETUPDATE.fields_by_name['market']._options = None
_EVENTEXPIRYFUTURESMARKETUPDATE.fields_by_name['expiry_futures_market_info']._options = None
_EVENTPERPETUALMARKETFUNDINGUPDATE.fields_by_name['funding']._options = None
_EVENTPERPETUALMARKETFUNDINGUPDATE.fields_by_name['funding_rate']._options = None
_EVENTPERPETUALMARKETFUNDINGUPDATE.fields_by_name['mark_price']._options = None
_EVENTSUBACCOUNTDEPOSIT.fields_by_name['amount']._options = None
_EVENTSUBACCOUNTWITHDRAW.fields_by_name['amount']._options = None
_EVENTSUBACCOUNTBALANCETRANSFER.fields_by_name['amount']._options = None
_DERIVATIVEMARKETORDERCANCEL.fields_by_name['market_order']._options = None
_DERIVATIVEMARKETORDERCANCEL.fields_by_name['cancel_quantity']._options = None
_EVENTCANCELDERIVATIVEORDER.fields_by_name['limit_order']._options = None
_EVENTCANCELDERIVATIVEORDER.fields_by_name['market_order_cancel']._options = None
_POINTSMULTIPLIER.fields_by_name['maker_points_multiplier']._options = None
_POINTSMULTIPLIER.fields_by_name['taker_points_multiplier']._options = None
_TRADINGREWARDCAMPAIGNBOOSTINFO.fields_by_name['spot_market_multipliers']._options = None
_TRADINGREWARDCAMPAIGNBOOSTINFO.fields_by_name['derivative_market_multipliers']._options = None
_CAMPAIGNREWARDPOOL.fields_by_name['max_campaign_rewards']._options = None
_FEEDISCOUNTTIERINFO.fields_by_name['maker_discount_rate']._options = None
_FEEDISCOUNTTIERINFO.fields_by_name['taker_discount_rate']._options = None
_FEEDISCOUNTTIERINFO.fields_by_name['staked_amount']._options = None
_FEEDISCOUNTTIERINFO.fields_by_name['fee_paid_amount']._options = None
_ACCOUNTREWARDS.fields_by_name['rewards']._options = None
# @@protoc_insertion_point(module_scope)
